@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR;
 
-our $DATE = '2015-10-23'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-10-29'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 our @Module_Lists = (
     {
@@ -91,6 +91,29 @@ _
             },
         ],
     },
+
+    {
+        summary => 'Ensuring only a single instance of program is running',
+        description => <<'_',
+
+There are a few common techniques to establish this: creating a PID file, and/or
+flock-ing a file (either the program's source code, or said PID file, or some
+other lock file). Note that when your script runs, the standard `DATA`
+filehandle is already open to the program's source code, so you can just use
+that for locking.
+
+Keywords: single process, prevent multiple instances, prevent multiple
+processes.
+
+_
+        entries => [
+            {module=>'Proc::PID::File', rating=>8},
+            {module=>'Proc::Pidfile', rating=>5},
+            {module=>'Proc::Govern', summary => 'Uses Proc::PID::File'},
+            {module=>'IPC::Lockfile', summary => 'Works by locking $0.lock'},
+            {module=>'Sys::RunAlone', summary => 'Works by locking DATA handle'},
+        ],
+    },
 );
 
 our @Author_Lists = (
@@ -135,7 +158,7 @@ Acme::CPANLists::PERLANCAR - PERLANCAR's CPAN lists
 
 =head1 VERSION
 
-This document describes version 0.06 of Acme::CPANLists::PERLANCAR (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2015-10-23.
+This document describes version 0.07 of Acme::CPANLists::PERLANCAR (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2015-10-29.
 
 =head1 DESCRIPTION
 
@@ -292,4 +315,34 @@ Alternate modules: L<File::Slurper>
 
 =back
 
+=head2 Ensuring only a single instance of program is running
+
+There are a few common techniques to establish this: creating a PID file, and/or
+flock-ing a file (either the program's source code, or said PID file, or some
+other lock file). Note that when your script runs, the standard C<DATA>
+filehandle is already open to the program's source code, so you can just use
+that for locking.
+
+Keywords: single process, prevent multiple instances, prevent multiple
+processes.
+
+
+=over
+
+=item * L<Proc::PID::File>
+
+Rating: 8/10
+
+=item * L<Proc::Pidfile>
+
+Rating: 5/10
+
+=item * L<Proc::Govern> - Uses Proc::PID::File
+
+=item * L<IPC::Lockfile> - Works by locking $0.lock
+
+=item * L<Sys::RunAlone> - Works by locking DATA handle
+
+=back
+
 =cut
